@@ -9,11 +9,11 @@ package org.mozilla.xpcom;
 
 public interface nsIAddonUpdateListener extends nsISupports
 {
-  String NS_IADDONUPDATELISTENER_IID =
+  public static final String NS_IADDONUPDATELISTENER_IID =
     "{bb86037c-98c1-4c22-8e03-1e4c9fc89a8e}";
 
-  void onStateChange(nsIUpdateItem arg1, short arg2, int arg3);
+  public void onStateChange(nsIUpdateItem arg1, short arg2, int arg3);
 
-  void onProgress(nsIUpdateItem arg1, long arg2, long arg3);
+  public void onProgress(nsIUpdateItem arg1, long arg2, long arg3);
 
 }
